# Trilium Next: Osobní znalostní databáze nové generace

V době, kdy se naše digitální poznámky rozptylují napříč různými aplikacemi a cloudy, hledáme nástroj, který by dokázal skutečně organizovat naše myšlenky do propojené a užitečné podoby. **Trilium Next** je právě tím řešením – moderní, open-source aplikace pro správu osobních znalostí, která vznikla jako komunitní fork původního projektu Trilium Notes.

## Co je Trilium Next?

Trilium Next je bezplatná a open-source, multiplatformní hierarchická aplikace pro tvorbu poznámek zaměřená na budování rozsáhlých osobních znalostních databází. Na rozdíl od jednoduchých poznámkových aplikací se Trilium Next specializuje na vytváření propojených, strukturovaných systémů znalostí, které dokážou růst společně s vašimi potřebami.

Aplikace využívá stromovou strukturu pro organizaci poznámek, přičemž poznámky mohou být uspořádány do libovolně hluboké hierarchie. Jediná poznámka může být umístěna na více místech ve stromu, což umožňuje flexibilní organizaci bez duplikování obsahu.

## Proč vznikl Trilium Next?

Původní projekt Trilium Notes přešel do maintenance módu, což znamená, že jeho autor zadam už neplánuje přidat žádné nové větší funkcionality. Trilium Next vznikl na začátku roku 2024 jako komunitní fork, protože upstream projekt vstoupil do fáze údržby a komunita chtěla aplikaci dále rozšiřovat.

Vývojáři se zatím zaměřili především na technické aspekty projektu, ale už nyní plánují vylepšení uživatelského zážitku. Dobrá zpráva je, že není nutná žádná migrace – Trilium Next může být spuštěn místo původního Trilium Notes a měl by fungovat bez problémů, protože bude používat stejnou databázi.

## Klíčové funkce a možnosti

### Bohatý editor a typy poznámek

Trilium Next nabízí mnohem víc než jen obyčejný textový editor:

- **WYSIWYG editor** s podporou tabulek, obrázků a matematických vzorců
- **Markdown autoformat** pro rychlé formátování během psaní
- **Zdrojový kód** s podporou syntax highlighting pro desítky programovacích jazyků
- **Canvas poznámky** s integrovaným Excalidraw pro kreslení diagramů a skic
- **Mermaid diagramy** pro tvorbu vývojových diagramů, grafů a schémat
- **Mind mapy** pro brainstorming a vizualizaci myšlenek
- **Relation mapy** pro zobrazení vztahů mezi poznámkami

### Pokročilé funkce organizace

**Klonování poznámek** je jednou z nejsilnějších funkcí. Stejná poznámka může existovat na více místech v hierarchii, aniž by se duplikoval obsah. Změny se automaticky promítnou všude.

**Note hoisting** umožňuje dočasně "zvednout" část stromu a pracovat pouze s ní, což je užitečné u rozsáhlých databází.

**Fulltextové vyhledávání** prohledává celý obsah včetně příloh a podporuje pokročilé dotazy.

### Internacionalizace a přístupnost

Uživatelské rozhraní je dostupné v angličtině, němčině, španělštině, francouzštině, rumunštině a čínštině (zjednodušené i tradiční).

### Bezpečnost a soukromí

Trilium Next nabízí **šifrované poznámky** s granularitou na úrovni jednotlivých poznámek. Přímá integrace OpenID a TOTP pro bezpečnější přihlášení zajišťuje, že vaše data zůstanou v bezpečí.

## Instalace a nasazení

### Desktop aplikace

Nejjednodušší způsob je stažení binárních souborů z GitHub releases. Aplikace je dostupná pro Linux, Windows i macOS.

Pro Arch Linux uživatele:
```bash
yay -S triliumnext-bin
```

### Server instalace

Trilium Next můžete hostovat na vlastním serveru pomocí Docker:

```bash
docker run -t -i -p 8080:8080 -v ~/trilium-data:/home/node/trilium-data triliumnext/notes
```

### Self-hosting výhody

Jako každý další self-hosted nástroj máte na výběr z více způsobů instalace TriliumNext. Vlastní hosting poskytuje:

- **Plnou kontrolu nad daty** – žádné třetí strany
- **Synchronizaci mezi zařízeními** prostřednictvím vlastního serveru
- **Přístup z mobilních zařízení** přes webové rozhraní
- **Neomezené úložiště** (omezeného pouze velikostí vašeho serveru)

## Praktické využití

### Osobní znalostní management

Trilium Next má všechny základy pokryté, s podporou markdown, obrázků, to-do seznamů a tabulek, spolu s interconnecting, mind mapami, vývojovými diagramy a bloky kódu pro pokročilejší uživatele.

### Studium a výzkum

Aplikace umožňuje vytvářet propojené poznámky podobně jako v Obsidian, ale s větší flexibilitou v organizaci. Funkce propojování poznámek umožňuje spojovat jednotlivé části teorie a rychle vyhledávat informace napříč různými tématy.

### Projekty a dokumentace

Pro složitější poznámky a znalostní databáze musíte být od začátku organizovanější. Není dobré jen tak házet všechno do kořenového adresáře – věřte mi, snadno se dostanete do nepořádku náhodných, nekategorizovaných poznámek.

### Programování a vývoj

Trilium Next nabízí vynikající podporu pro programátory:
- Syntax highlighting pro desítky jazyků
- Správa code snippetů
- Dokumentace projektů
- Integration s Git workflow (díky markdown exportu)

## Migrace z jiných systémů

### Z původního Trilium

Není potřeba žádných speciálních migračních kroků pro přechod z zadam/Trilium instance na TriliumNext/Notes instanci.
Jednoduše nainstalujte TriliumNext/Notes obvyklým způsobem a bude používat vaši existující databázi.

### Import z jiných aplikací

Trilium Next podporuje import z:
- **Evernote** (.enex soubory)
- **Markdown** soubory
- **HTML** soubory
- **Plain text** soubory

## Technické specifikace

### Výkon a škálovatelnost

Aplikace se dobře škáluje jak v použitelnosti, tak ve výkonu až na 100 000 poznámek, což z ní dělá vhodnou volbu i pro velmi rozsáhlé znalostní databáze.

### Multiplatformní podpora

- **Desktop**: Linux, Windows, macOS (omezená podpora)
- **Web**: Moderní prohlížeče (Chrome, Firefox)
- **Mobile**: Webové rozhraní optimalizované pro dotykové zařízení

### Synchronizace

Trilium Next nabízí robustní synchronizaci mezi zařízeními prostřednictvím vlastního sync serveru, což zajišťuje, že vaše poznámky jsou vždy aktuální na všech vašich zařízeních.

## Budoucnost projektu

TriliumNext Notes se přejmenuje zpět na Trilium Notes, protože @zadam byl tak laskavý a dal nám původní název. Toto symbolizuje skutečné převzetí štafety komunitou.

Současný vývoj se zaměřuje na:
- **Technickou stabilitu** a přechod na TypeScript
- **Vylepšení uživatelského rozhraní** včetně nových témat
- **Lepší dokumentaci** přesunutou přímo do aplikace
- **Rozšíření funkcí** na základě požadavků komunity

## Alternativy a srovnání

Trilium Next konkuruje aplikacím jako:
- **Obsidian** – ale nabízí lepší stromovou organizaci
- **Logseq** – ale s jednodušším self-hostingem  
- **Notion** – ale s plnou kontrolou nad daty
- **Joplin** – ale s pokročilejšími funkcemi propojení

## Závěr

Trilium Next představuje vynikající volbu pro každého, kdo hledá mocný nástroj pro správu osobních znalostí s důrazem na soukromí a flexibilitu. Kombinuje sílu hierarchické organizace s moderními funkcemi jako jsou mind mapy, diagramy a pokročilé propojování poznámek.

Pro Linux uživatele a privacy-conscious jednotlivce je Trilium Next téměř ideální volbou – nabízí plnou kontrolu nad daty, robustní funkcionalitu a aktivní komunitní vývoj. Zatímco je technicky v maintenance stavu, TriliumNext verze aplikace je více než dostatečná pro pokrytí vašich potřeb, ať už jste programátor zatížený svými kódovými soubory nebo profesionál hledající robustní způsob, jak si zaznamenávat důležité aspekty svých schůzek.

Trilium Next není jen další poznámková aplikace – je to platforma pro budování vašeho osobního systému znalostí, který může růst a přizpůsobovat se vašim měnícím se potřebám po celý život.

---

*Trilium Next je dostupný zdarma na [GitHub](https://github.com/TriliumNext/Notes) pod licencí AGPL-2.0. Komunita aktivně vítá příspěvky a zpětnou vazbu od uživatelů.*
